===================
django-authorizenet
===================

Django integration with Authorize.NET payment gateway.
Includes SIM and AIM implementations.

Usage example:
https://github.com/zen4ever/django-authorizenet/tree/master/sample_project

Authors: https://github.com/zen4ever/django-authorizenet/contributors
